@@ -6,7 +6,7 @@ def check(ctx):
     """
     Check Python package distribution manifest.
     """
-    ctx.run('check-manifest -v')
+    ctx.run("check-manifest -v")
 
 
 @invoke.task
@@ -14,7 +14,7 @@ def build(ctx):
     """
     Build Python package distribution locally.
     """
-    ctx.run('python setup.py sdist')
+    ctx.run("python setup.py sdist bdist_wheel")
 
 
 @invoke.task(check, build)
@@ -22,4 +22,4 @@ def upload(ctx):
     """
     Check, build, and upload Python package distribution to local PyPI.
     """
-    ctx.run('twine upload dist/* -r scoota-pypi')
+    ctx.run("twine upload dist/* -r scoota-pypi")
