@@ -1,5 +1,6 @@
 import logging
 
+from google.api_core.retry import Retry
 from google.api_core.exceptions import AlreadyExists, GoogleAPIError
 from google.cloud import tasks_v2
 
@@ -9,7 +10,7 @@ logger = logging.getLogger(__name__)
 class Queue:
     """Utility class to create queues and tasks in Google Cloud Tasks."""
 
-    def __init__(self, project_id, location, queue_name, service='default'):
+    def __init__(self, project_id, location, queue_name, service="default"):
         """Initialise the Google Cloud Queue.
 
         Parameters:
@@ -26,12 +27,24 @@ class Queue:
 
         """
         self.client = tasks_v2.CloudTasksClient()
-        self.location = f'projects/{project_id}/locations/{location}'
+        self.location = f"projects/{project_id}/locations/{location}"
         self.service = service
 
         name = self.client.queue_path(project_id, location, queue_name)
         self.queue = tasks_v2.Queue(name=name)
 
+    @property
+    def retry(self):
+        """Exponential retry decorator.
+
+        This class is a decorator used to add exponential back-off retry behavior to the
+        create_task RPC call.
+
+        We implement it here as a property of the queue, first to always use the same retry logic,
+        and second to allow us to mock it more easily in tests.
+        """
+        return Retry(initial=0.1, maximum=60, multiplier=1.3, deadline=600)
+
     def create(self):
         try:
             self.client.create_queue(parent=self.location, queue=self.queue)
@@ -40,7 +53,7 @@ class Queue:
         except GoogleAPIError as e:
             logger.exception(e)
 
-    def enqueue(self, uri, headers=None, method='POST', payload=None, service=None):
+    def enqueue(self, uri, headers=None, method="POST", payload=None, service=None):
         """Create a task in the queue.
 
         This will create an App Engine HTTP request. The task will be delivered to the App Engine
@@ -68,25 +81,22 @@ class Queue:
 
         """
         http_method = {
-            'GET': tasks_v2.HttpMethod.GET,
-            'POST': tasks_v2.HttpMethod.POST,
-        }.get(
-            method,
-            tasks_v2.HttpMethod.GET
-        )
+            "GET": tasks_v2.HttpMethod.GET,
+            "POST": tasks_v2.HttpMethod.POST,
+        }.get(method, tasks_v2.HttpMethod.GET)
 
         task = {
-            'app_engine_http_request': {
-                'app_engine_routing': {'service': service or self.service},
-                'headers': headers or {},
-                'http_method': http_method,
-                'relative_uri': uri,
+            "app_engine_http_request": {
+                "app_engine_routing": {"service": service or self.service},
+                "headers": headers or {},
+                "http_method": http_method,
+                "relative_uri": uri,
             }
         }
         if payload:
-            task['app_engine_http_request']['body'] = payload
+            task["app_engine_http_request"]["body"] = payload
 
         try:
-            self.client.create_task(parent=self.queue.name, task=task)
+            self.client.create_task(parent=self.queue.name, task=task, retry=self.retry)
         except GoogleAPIError as e:
             logger.exception(e)
